
0.4.1 (2015-09-14)
##################

Changes since 0.4.0 (2015-09-09).

Bug Fixes
$$$$$$$$$

* fixes `#274 <https://github.com/biocommons/hgvs/issues/274/>`_, `#275 <https://github.com/biocommons/hgvs/issues/275/>`_: initialize normalizer with same alt_aln_method as EasyVariantMapper [`BROKEN: 43e174d6f8af <https://github.com/biocommons/hgvs/commit/43e174d6f8af>`_]
* fixes `#276 <https://github.com/biocommons/hgvs/issues/276/>`_: raise error when user attempts to map to/from c. with non-coding transcript [`BROKEN: 3f7b659f4f02 <https://github.com/biocommons/hgvs/commit/3f7b659f4f02>`_]
